==> vega_embed_flutter-0.6.0.tar.gz: CHANGELOG.md <==
## [0.6.0] - 11 June 2020

- Added support for webview to enable vega lite chart for mobile.
- utilizes the flutter webview_flutter

## [0.5.0] - [0.5.0+2] - 23 April 2020.

- Added more vega embed options and tested.
- Added more examples for embed options.
- Now the demo page includes code samples.
- Edited the example md to include live page and corrected some spelling errors.

## [0.1.1+1] - [0.1.1+3] - 17 March 2020.

- edited the example section.
- added git hub actions.

## [0.1.1] - 16 March 2020.

- Now the widget accepts and passes the VegaEmbedOptions.
- Created a full fledged demo page.
- Example includes better documentation.

## [0.1.0] - 10 March 2020.

- Removed double Rendering.
  - Now uses the vega-embed and vega-tool tip styles directly.
- Multiple Charts in Single page is working now.
- Changed the example folder structure.
- Renamed VegaLiteSchemLocation to VegaLiteSpecLocation.
- Differentiating Schema vs Spec.

## [0.0.1] - 06 March 2020.

- A basic version of vega_embed for flutter.
  - Works with single charts.
  - Interactions works as well.

TODO:

- Enable flutter webview to support mobile platform.
- Extend vega-embed options to fully suport all options.
- [x] ~~Provide more vega-lite references.~~
- [x] ~~Document the theming section~~
- [x] ~~Add a section vega-embed options.~~
- [x] ~~Add a definitve and documented demo. A basic example is available in the exampe folder.~~
- [x] ~~Set up a live page with mutltitude of charts.~~
- [x] ~~Enable vega-embed theming.~~
- [x] ~~Work on rendering multiple charts in the same page.~~

==> vega_embed_flutter-0.6.2.tar.gz: CHANGELOG.md <==
## [0.6.2] 27 August 2020

- Some fixes for improving the scores.
- Remove menu from the webview render of vega charts when no actions provided.
- add relevant style sheet for vega-embed in webview.

## [0.6.0+3] 24 June 2020

- Upgraded freezed package version.
- Edited the example demo page.

## [0.6.0] - [0.6.0+2] 11 June 2020

- Added support for webview to enable vega lite chart for mobile.
- utilizes the flutter webview_flutter

## [0.5.0] - [0.5.0+2] - 23 April 2020.

- Added more vega embed options and tested.
- Added more examples for embed options.
- Now the demo page includes code samples.
- Edited the example md to include live page and corrected some spelling errors.

## [0.1.1+1] - [0.1.1+3] - 17 March 2020.

- edited the example section.
- added git hub actions.

## [0.1.1] - 16 March 2020.

- Now the widget accepts and passes the VegaEmbedOptions.
- Created a full fledged demo page.
- Example includes better documentation.

## [0.1.0] - 10 March 2020.

- Removed double Rendering.
  - Now uses the vega-embed and vega-tool tip styles directly.
- Multiple Charts in Single page is working now.
- Changed the example folder structure.
- Renamed VegaLiteSchemLocation to VegaLiteSpecLocation.
- Differentiating Schema vs Spec.

## [0.0.1] - 06 March 2020.

- A basic version of vega_embed for flutter.
  - Works with single charts.
  - Interactions works as well.

TODO:

- [X] Enable flutter webview to support mobile platform.
- Extend vega-embed options to fully support all options.
- [x] ~~Provide more vega-lite references.~~
- [x] ~~Document the theming section~~
- [x] ~~Add a section vega-embed options.~~
- [x] ~~Add a definitive and documented demo. A basic example is available in the example folder.~~
- [x] ~~Set up a live page with multitude of charts.~~
- [x] ~~Enable vega-embed theming.~~
- [x] ~~Work on rendering multiple charts in the same page.~~
